@@ -190,7 +190,7 @@ tags_meta = [
             Project database. See the `SurfacePropDoc` schema for a full list of fields returned by this route.",
     },
     {
-        "name": "Robocrystallographer",
+        "name": "Materials Robocrystallographer",
         "description": "Route providing a computed text description for a material following the \
             methodology discussed by [Ganose *et al.*](https://doi.org/10.1557/mrc.2019.94) \
             Note that descriptions may not been calculated for all materials in the Materials \
@@ -204,11 +204,12 @@ tags_meta = [
             Project database. See the `SynthesisSearchResultModel` schema for a full list of fields returned by this route.",
     },
     {
-        "name": "Electrodes",
+        "name": "Materials Electrodes",
         "description": "Route providing computed electrode data for a material following the \
             methodology discussed by [Shen *et al.*](https://doi.org/10.1038/s41524-020-00422-3) \
             Note that electrode data has not been calculated for all materials in the Materials \
-            Project database. See the `InsertionElectrodeDoc` schema for a full list of fields returned by this route.",
+            Project database. See the `InsertionElectrodeDoc` and `ConversionElectrodeDoc` schema \
+            for a full list of fields returned by this route.",
     },
     {
         "name": "Materials Oxidation States",
@@ -235,8 +236,12 @@ tags_meta = [
     {
         "name": "Materials Alloys",
         "description": "Route for retrevial of information about which hypothetical alloy(s) a given material might "
-                       "belong to, following the methodolgy discussed by "
-                       "[Woods-Robinson, Horton and Persson](https://arxiv.org/pdf/2206.10715)."
+        "belong to, following the methodolgy discussed by "
+        "[Woods-Robinson, Horton and Persson](https://arxiv.org/pdf/2206.10715).",
+    },
+    {
+        "name": "Materials Bonds",
+        "description": "Route for retrevial of bonding information for a given material.",
     },
     {
         "name": "MPComplete",
@@ -254,7 +259,7 @@ tags_meta = [
         "description": "Route for basic task information for DFT calculations in the Materials Project \
             molecules database. Multiple calculations can ultimately be associated with a unique molecule, \
             and are the source of its reported properties. The unique identifier for a calculation is its \
-            `task_id`. See the `TaskDocument` schema for a full list of fields returned by this route."
+            `task_id`. See the `TaskDocument` schema for a full list of fields returned by this route.",
     },
     {
         "name": "Associated Molecules",
@@ -265,7 +270,7 @@ tags_meta = [
             and connectivity (based on molecular graph isomorphism) are collected, forming the 'core' molecules \
             collection. This route provides access to data for individual 'associated molecules'. The 'Core Molecules' \
             route (/molecules/molecules/) contains data for core molecules. See the `MoleculeDoc` schema for a full list \
-            of fields returned by this route."
+            of fields returned by this route.",
     },
     {
         "name": "Core Molecules",
@@ -276,47 +281,52 @@ tags_meta = [
             and connectivity (based on molecular graph isomorphism) are collected, forming the 'core' molecules \
             collection. This route provides access to data for individual 'associated molecules'. The 'Associated Molecules' \
             route (/molecules/assoc/) contains data for 'associated' molecules. See the `MoleculeDoc` schema for a full list \
-            of fields returned by this route."
+            of fields returned by this route.",
     },
     {
         "name": "Molecules Partial Charges",
         "description": "Route for molecular partial charge data. See the `PartialChargesDoc` schema for a full list \
-            of fields returned by this route."
+            of fields returned by this route.",
     },
     {
         "name": "Molecules Partial Spins",
         "description": "Route for molecular partial spin data. See the `PartialSpinsDoc` schema for a full list \
-            of fields returned by this route."
+            of fields returned by this route.",
     },
     {
         "name": "Molecules Bonds",
         "description": "Route for molecular bonding data. See the `MoleculeBondingDoc` schema for a full list \
-            of fields returned by this route."
+            of fields returned by this route.",
+    },
+    {
+        "name": "Molecules Metal Binding",
+        "description": "Route for data regarding metal binding to molecules. See the `MetalBindingDoc` schema \
+            for a full list of fields returned by this route.",
     },
     {
         "name": "Molecules Orbitals",
         "description": "Route for molecular orbital information obtained via Natural Bonding Orbital analysis. \
-            See the `OrbitalDoc` schema for a full list of fields returned by this route."
+            See the `OrbitalDoc` schema for a full list of fields returned by this route.",
     },
     {
         "name": "Molecules Redox",
         "description": "Route for molecular redox information (e.g. ionization energy, reduction free energy, \
-            redox potentials). See the `RedoxDoc` schema for a full list of fields returned by this route."
+            redox potentials). See the `RedoxDoc` schema for a full list of fields returned by this route.",
     },
     {
         "name": "Molecules Thermo",
         "description": "Route for molecular thermochemistry information. See the `MoleculeThermoDoc` schema for \
-            a full list of fields returned by this route."
+            a full list of fields returned by this route.",
     },
     {
         "name": "Molecules Vibrations",
         "description": "Route for molecular normal mode and IR spectroscopy data. See the `VibrationDoc` schema for \
-            a full list of fields returned by this route."
+            a full list of fields returned by this route.",
     },
     {
         "name": "Molecules Summary",
         "description": "Route for a summary of all data calculated on 'core' molecules in the Materials Project \
-            molecules database. See the `MoleculeSummaryDoc` schema for a full list of fields returned by this route."
+            molecules database. See the `MoleculeSummaryDoc` schema for a full list of fields returned by this route.",
     },
     {
         "name": "JCESR Electrolyte Genome",
