@@ -1,5 +1,6 @@
 from maggma.api.resource import ReadOnlyResource
 from emmet.core.dois import DOIDoc
+from emmet.api.routes.materials.materials.query_operators import MultiMaterialIDQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
 from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
 from emmet.api.core.settings import MAPISettings
@@ -10,14 +11,14 @@ def dois_resource(dois_store):
         dois_store,
         DOIDoc,
         query_operators=[
+            MultiMaterialIDQuery(),
             PaginationQuery(),
-            SparseFieldsQuery(DOIDoc, default_fields=["task_id", "doi"]),
+            SparseFieldsQuery(DOIDoc, default_fields=["material_id", "doi"]),
         ],
         header_processor=GlobalHeaderProcessor(),
         tags=["DOIs"],
-        enable_default_search=False,
         disable_validation=True,
-        timeout=MAPISettings().TIMEOUT,
+        timeout=MAPISettings().TIMEOUT,  # type: ignore
     )
 
     return resource
