@@ -1,7 +1,7 @@
 from maggma.api.resource import ReadOnlyResource
 from emmet.core.molecules_jcesr import MoleculesDoc
 
-from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
+from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
 from emmet.api.routes.legacy.jcesr.query_operators import (
     MoleculeBaseQuery,
     MoleculeElementsQuery,
@@ -21,7 +21,6 @@ def jcesr_resource(molecules_store):
             MoleculeElementsQuery(),
             MoleculeFormulaQuery(),
             MultipleTaskIDsQuery(),
-            SortQuery(),
             PaginationQuery(),
             SparseFieldsQuery(MoleculesDoc, default_fields=["task_id"]),
         ],
@@ -29,7 +28,7 @@ def jcesr_resource(molecules_store):
         tags=["JCESR Electrolyte Genome"],
         sub_path="/jcesr/",
         disable_validation=True,
-        timeout=MAPISettings().TIMEOUT
+        timeout=MAPISettings().TIMEOUT,
     )
 
     return resource
