@@ -1,4 +1,8 @@
-from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery, NumericQuery
+from maggma.api.query_operator import (
+    PaginationQuery,
+    SparseFieldsQuery,
+    NumericQuery,
+)
 from maggma.api.resource import ReadOnlyResource
 
 from emmet.api.core.global_header import GlobalHeaderProcessor
@@ -24,9 +28,11 @@ def absorption_resource(absorption_store):
                     "energy_max",
                 ],
             ),
-            SortQuery(),
             PaginationQuery(),
-            SparseFieldsQuery(AbsorptionDoc, default_fields=["material_id", "last_updated"],),
+            SparseFieldsQuery(
+                AbsorptionDoc,
+                default_fields=["material_id", "last_updated"],
+            ),
         ],
         header_processor=GlobalHeaderProcessor(),
         tags=["Materials Absorption"],
