@@ -1,7 +1,7 @@
 from maggma.api.resource import ReadOnlyResource
 from emmet.core.polar import DielectricDoc
 
-from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
+from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
 from emmet.api.routes.materials.dielectric.query_operators import DielectricQuery
 from emmet.api.routes.materials.materials.query_operators import MultiMaterialIDQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
@@ -15,9 +15,10 @@ def dielectric_resource(dielectric_store):
         query_operators=[
             MultiMaterialIDQuery(),
             DielectricQuery(),
-            SortQuery(),
             PaginationQuery(),
-            SparseFieldsQuery(DielectricDoc, default_fields=["material_id", "last_updated"]),
+            SparseFieldsQuery(
+                DielectricDoc, default_fields=["material_id", "last_updated"]
+            ),
         ],
         header_processor=GlobalHeaderProcessor(),
         tags=["Materials Dielectric"],
