@@ -1,7 +1,8 @@
 from maggma.api.resource import ReadOnlyResource
-from emmet.core.elasticity_legacy import ElasticityDoc
+from emmet.core.elasticity import ElasticityDoc
 from emmet.api.core.global_header import GlobalHeaderProcessor
-from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
+from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
+from emmet.api.routes.materials.materials.query_operators import MultiMaterialIDQuery
 from emmet.api.routes.materials.elasticity.query_operators import (
     ElasticityChemsysQuery,
     BulkModulusQuery,
@@ -17,21 +18,22 @@ def elasticity_resource(elasticity_store):
         elasticity_store,
         ElasticityDoc,
         query_operators=[
+            MultiMaterialIDQuery(),
             ElasticityChemsysQuery(),
             BulkModulusQuery(),
             ShearModulusQuery(),
             PoissonQuery(),
-            SortQuery(),
             PaginationQuery(),
             SparseFieldsQuery(
-                ElasticityDoc, default_fields=["task_id", "pretty_formula"],
+                ElasticityDoc,
+                default_fields=["material_id", "formula_pretty"],
             ),
         ],
         header_processor=GlobalHeaderProcessor(),
         tags=["Materials Elasticity"],
         sub_path="/elasticity/",
-        disable_validation=False,
-        timeout=MAPISettings().TIMEOUT
+        disable_validation=True,
+        timeout=MAPISettings().TIMEOUT,
     )
 
     return resource
