@@ -1,8 +1,8 @@
-from maggma.api.query_operator.dynamic import NumericQuery
 from maggma.api.resource import ReadOnlyResource
 from emmet.core.eos import EOSDoc
+from emmet.api.routes.materials.materials.query_operators import MultiMaterialIDQuery
 
-from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
+from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
 from emmet.api.core.settings import MAPISettings
 
@@ -12,8 +12,7 @@ def eos_resource(eos_store):
         eos_store,
         EOSDoc,
         query_operators=[
-            NumericQuery(model=EOSDoc),
-            SortQuery(),
+            MultiMaterialIDQuery(),
             PaginationQuery(),
             SparseFieldsQuery(EOSDoc, default_fields=["task_id"]),
         ],
@@ -21,7 +20,7 @@ def eos_resource(eos_store):
         tags=["Materials EOS"],
         sub_path="/eos/",
         disable_validation=True,
-        timeout=MAPISettings().TIMEOUT
+        timeout=MAPISettings().TIMEOUT,
     )
 
     return resource
