@@ -1,7 +1,7 @@
 from maggma.api.resource import ReadOnlyResource
 from emmet.core.magnetism import MagnetismDoc
 
-from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
+from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
 from emmet.api.routes.materials.magnetism.query_operators import MagneticQuery
 from emmet.api.routes.materials.materials.query_operators import MultiMaterialIDQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
@@ -15,9 +15,10 @@ def magnetism_resource(magnetism_store):
         query_operators=[
             MultiMaterialIDQuery(),
             MagneticQuery(),
-            SortQuery(),
             PaginationQuery(),
-            SparseFieldsQuery(MagnetismDoc, default_fields=["material_id", "last_updated"]),
+            SparseFieldsQuery(
+                MagnetismDoc, default_fields=["material_id", "last_updated"]
+            ),
         ],
         header_processor=GlobalHeaderProcessor(),
         tags=["Materials Magnetism"],
