@@ -1,14 +1,15 @@
 from maggma.api.resource import ReadOnlyResource
 from emmet.core.xas import XASDoc
 
-from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
+from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
+from emmet.api.routes.materials.materials.query_operators import MultiMaterialIDQuery
 from emmet.api.routes.materials.materials.query_operators import (
     ElementsQuery,
     FormulaQuery,
     ChemsysQuery,
 )
 from emmet.api.core.global_header import GlobalHeaderProcessor
-from emmet.api.routes.materials.xas.query_operators import XASQuery, XASTaskIDQuery
+from emmet.api.routes.materials.xas.query_operators import XASQuery, XASIDQuery
 from emmet.api.core.settings import MAPISettings
 
 
@@ -17,12 +18,12 @@ def xas_resource(xas_store):
         xas_store,
         XASDoc,
         query_operators=[
+            MultiMaterialIDQuery(),
             FormulaQuery(),
             ChemsysQuery(),
             ElementsQuery(),
             XASQuery(),
-            XASTaskIDQuery(),
-            SortQuery(),
+            XASIDQuery(),
             PaginationQuery(),
             SparseFieldsQuery(
                 XASDoc,
@@ -41,7 +42,7 @@ def xas_resource(xas_store):
         tags=["Materials XAS"],
         sub_path="/xas/",
         disable_validation=True,
-        timeout=MAPISettings().TIMEOUT,
+        timeout=MAPISettings().TIMEOUT,  # type: ignore
     )
 
     return resource
