@@ -1,4 +1,4 @@
-from typing import Any, Optional
+from typing import Any, Optional, Dict
 from fastapi import Query
 from maggma.api.query_operator import QueryOperator
 from maggma.api.utils import STORE_PARAMS
@@ -13,49 +13,46 @@ class NBOPopulationQuery(QueryOperator):
         self,
         electron_type_population: Optional[str] = Query(
             None,
-            description="Should alpha ('alpha'), beta ('beta'), or all electrons be considered (None; default)?"
+            description="Should alpha ('alpha'), beta ('beta'), or all electrons be considered (None; default)?",
         ),
         min_core_electrons: Optional[float] = Query(
             None,
-            description="Minimum number of core electrons in an atom in this molecule."
+            description="Minimum number of core electrons in an atom in this molecule.",
         ),
         max_core_electrons: Optional[float] = Query(
             None,
-            description="Maximum number of core electrons in an atom in this molecule."
+            description="Maximum number of core electrons in an atom in this molecule.",
         ),
         min_valence_electrons: Optional[float] = Query(
             None,
-            description="Minimum number of valence electrons in an atom in this molecule."
+            description="Minimum number of valence electrons in an atom in this molecule.",
         ),
         max_valence_electrons: Optional[float] = Query(
             None,
-            description="Maximum number of valence electrons in an atom in this molecule."
+            description="Maximum number of valence electrons in an atom in this molecule.",
         ),
         min_rydberg_electrons: Optional[float] = Query(
             None,
-            description="Minimum number of Rydberg electrons in an atom in this molecule."
+            description="Minimum number of Rydberg electrons in an atom in this molecule.",
         ),
         max_rydberg_electrons: Optional[float] = Query(
             None,
-            description="Maximum number of Rydberg electrons in an atom in this molecule."
+            description="Maximum number of Rydberg electrons in an atom in this molecule.",
         ),
         min_total_electrons: Optional[float] = Query(
-            None,
-            description="Minimum number of electrons in an atom in this molecule."
+            None, description="Minimum number of electrons in an atom in this molecule."
         ),
         max_total_electrons: Optional[float] = Query(
-            None,
-            description="Maximum number of electrons in an atom in this molecule."
+            None, description="Maximum number of electrons in an atom in this molecule."
         ),
     ) -> STORE_PARAMS:
-
         crit: Dict[str, Any] = dict()  # type: ignore
 
         d = {
             "core_electrons": [min_core_electrons, max_core_electrons],
             "valence_electrons": [min_valence_electrons, max_valence_electrons],
             "rydberg_electrons": [min_rydberg_electrons, max_rydberg_electrons],
-            "total_electrons": [min_total_electrons, max_total_electrons]
+            "total_electrons": [min_total_electrons, max_total_electrons],
         }
 
         if electron_type_population is None:
@@ -67,9 +64,13 @@ class NBOPopulationQuery(QueryOperator):
                 elif electron_type_population.lower() == "beta":
                     prefix = "beta_population."
                 else:
-                    raise ValueError("electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!")
+                    raise ValueError(
+                        "electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!"
+                    )
             except AttributeError:
-                raise ValueError("electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!")
+                raise ValueError(
+                    "electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!"
+                )
 
         for entry in d:
             key = prefix + entry
@@ -85,19 +86,21 @@ class NBOPopulationQuery(QueryOperator):
         return {"criteria": crit}
 
     def ensure_indexes(self):  # pragma: no cover
-        return [("open_shell", False),
-                ("nbo_population.core_electrons", False),
-                ("nbo_population.valence_electrons", False),
-                ("nbo_population.rydberg_electrons", False),
-                ("nbo_population.total_electrons", False),
-                ("alpha_population.core_electrons", False),
-                ("alpha_population.valence_electrons", False),
-                ("alpha_population.rydberg_electrons", False),
-                ("alpha_population.total_electrons", False),
-                ("beta_population.core_electrons", False),
-                ("beta_population.valence_electrons", False),
-                ("beta_population.rydberg_electrons", False),
-                ("beta_population.total_electrons", False)]
+        return [
+            ("open_shell", False),
+            ("nbo_population.core_electrons", False),
+            ("nbo_population.valence_electrons", False),
+            ("nbo_population.rydberg_electrons", False),
+            ("nbo_population.total_electrons", False),
+            ("alpha_population.core_electrons", False),
+            ("alpha_population.valence_electrons", False),
+            ("alpha_population.rydberg_electrons", False),
+            ("alpha_population.total_electrons", False),
+            ("beta_population.core_electrons", False),
+            ("beta_population.valence_electrons", False),
+            ("beta_population.rydberg_electrons", False),
+            ("beta_population.total_electrons", False),
+        ]
 
 
 class NBOLonePairQuery(QueryOperator):
@@ -109,51 +112,49 @@ class NBOLonePairQuery(QueryOperator):
         self,
         electron_type_lp: Optional[str] = Query(
             None,
-            description="Should alpha ('alpha'), beta ('beta'), or all electrons be considered (None; default)?"
+            description="Should alpha ('alpha'), beta ('beta'), or all electrons be considered (None; default)?",
         ),
         lp_type: Optional[str] = Query(
             None,
-            description="Type of orbital - 'LP' for 'lone pair' or 'LV' for 'lone vacant'"
+            description="Type of orbital - 'LP' for 'lone pair' or 'LV' for 'lone vacant'",
         ),
         min_s_character: Optional[float] = Query(
             None,
-            description="Minimum percentage of the lone pair constituted by s atomic orbitals."
+            description="Minimum percentage of the lone pair constituted by s atomic orbitals.",
         ),
         max_s_character: Optional[float] = Query(
             None,
-            description="Maximum percentage of the lone pair constituted by s atomic orbitals."
+            description="Maximum percentage of the lone pair constituted by s atomic orbitals.",
         ),
         min_p_character: Optional[float] = Query(
             None,
-            description="Minimum percentage of the lone pair constituted by p atomic orbitals."
+            description="Minimum percentage of the lone pair constituted by p atomic orbitals.",
         ),
         max_p_character: Optional[float] = Query(
             None,
-            description="Maximum percentage of the lone pair constituted by p atomic orbitals."
+            description="Maximum percentage of the lone pair constituted by p atomic orbitals.",
         ),
         min_d_character: Optional[float] = Query(
             None,
-            description="Minimum percentage of the lone pair constituted by d atomic orbitals."
+            description="Minimum percentage of the lone pair constituted by d atomic orbitals.",
         ),
         max_d_character: Optional[float] = Query(
             None,
-            description="Maximum percentage of the lone pair constituted by d atomic orbitals."
+            description="Maximum percentage of the lone pair constituted by d atomic orbitals.",
         ),
         min_f_character: Optional[float] = Query(
             None,
-            description="Minimum percentage of the lone pair constituted by f atomic orbitals."
+            description="Minimum percentage of the lone pair constituted by f atomic orbitals.",
         ),
         max_f_character: Optional[float] = Query(
             None,
-            description="Maximum percentage of the lone pair constituted by f atomic orbitals."
+            description="Maximum percentage of the lone pair constituted by f atomic orbitals.",
         ),
         min_lp_occupancy: Optional[float] = Query(
-            None,
-            description="Minimum number of electrons in the lone pair."
+            None, description="Minimum number of electrons in the lone pair."
         ),
         max_lp_occupancy: Optional[float] = Query(
-            None,
-            description="Maximum number of electrons in the lone pair."
+            None, description="Maximum number of electrons in the lone pair."
         ),
     ) -> STORE_PARAMS:
         crit: Dict[str, Any] = dict()  # type: ignore
@@ -175,9 +176,13 @@ class NBOLonePairQuery(QueryOperator):
                 elif electron_type_lp.lower() == "beta":
                     prefix = "beta_lone_pairs."
                 else:
-                    raise ValueError("electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!")
+                    raise ValueError(
+                        "electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!"
+                    )
             except AttributeError:
-                raise ValueError("electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!")
+                raise ValueError(
+                    "electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!"
+                )
 
         for entry in d:
             key = prefix + entry
@@ -203,7 +208,7 @@ class NBOLonePairQuery(QueryOperator):
             "d_character",
             "f_character",
             "occupancy",
-            "type_code"
+            "type_code",
         ]
         indices = list()
         for p in prefixes:
@@ -221,99 +226,97 @@ class NBOBondQuery(QueryOperator):
         self,
         electron_type_bond: Optional[str] = Query(
             None,
-            description="Should alpha ('alpha'), beta ('beta'), or all electrons be considered (None; default)?"
+            description="Should alpha ('alpha'), beta ('beta'), or all electrons be considered (None; default)?",
         ),
         bond_type: Optional[str] = Query(
             None,
-            description="Type of orbital, e.g. 'BD' for bonding or 'BD*' for antibonding"
+            description="Type of orbital, e.g. 'BD' for bonding or 'BD*' for antibonding",
         ),
         min_s_character_atom1: Optional[float] = Query(
             None,
-            description="Minimum percentage of the bond constituted by s atomic orbitals on the first atom."
+            description="Minimum percentage of the bond constituted by s atomic orbitals on the first atom.",
         ),
         max_s_character_atom1: Optional[float] = Query(
             None,
-            description="Maximum percentage of the bond constituted by s atomic orbitals on the first atom."
+            description="Maximum percentage of the bond constituted by s atomic orbitals on the first atom.",
         ),
         min_s_character_atom2: Optional[float] = Query(
             None,
-            description="Minimum percentage of the bond constituted by s atomic orbitals on the second atom."
+            description="Minimum percentage of the bond constituted by s atomic orbitals on the second atom.",
         ),
         max_s_character_atom2: Optional[float] = Query(
             None,
-            description="Maximum percentage of the bond constituted by s atomic orbitals on the second atom."
+            description="Maximum percentage of the bond constituted by s atomic orbitals on the second atom.",
         ),
         min_p_character_atom1: Optional[float] = Query(
             None,
-            description="Minimum percentage of the bond constituted by p atomic orbitals on the first atom."
+            description="Minimum percentage of the bond constituted by p atomic orbitals on the first atom.",
         ),
         max_p_character_atom1: Optional[float] = Query(
             None,
-            description="Maximum percentage of the bond constituted by p atomic orbitals on the first atom."
+            description="Maximum percentage of the bond constituted by p atomic orbitals on the first atom.",
         ),
         min_p_character_atom2: Optional[float] = Query(
             None,
-            description="Minimum percentage of the bond constituted by p atomic orbitals on the second atom."
+            description="Minimum percentage of the bond constituted by p atomic orbitals on the second atom.",
         ),
         max_p_character_atom2: Optional[float] = Query(
             None,
-            description="Maximum percentage of the bond constituted by p atomic orbitals on the second atom."
+            description="Maximum percentage of the bond constituted by p atomic orbitals on the second atom.",
         ),
         min_d_character_atom1: Optional[float] = Query(
             None,
-            description="Minimum percentage of the bond constituted by d atomic orbitals on the first atom."
+            description="Minimum percentage of the bond constituted by d atomic orbitals on the first atom.",
         ),
         max_d_character_atom1: Optional[float] = Query(
             None,
-            description="Maximum percentage of the bond constituted by d atomic orbitals on the first atom."
+            description="Maximum percentage of the bond constituted by d atomic orbitals on the first atom.",
         ),
         min_d_character_atom2: Optional[float] = Query(
             None,
-            description="Minimum percentage of the bond constituted by d atomic orbitals on the second atom."
+            description="Minimum percentage of the bond constituted by d atomic orbitals on the second atom.",
         ),
         max_d_character_atom2: Optional[float] = Query(
             None,
-            description="Maximum percentage of the bond constituted by d atomic orbitals on the second atom."
+            description="Maximum percentage of the bond constituted by d atomic orbitals on the second atom.",
         ),
         min_f_character_atom1: Optional[float] = Query(
             None,
-            description="Minimum percentage of the bond constituted by f atomic orbitals on the first atom."
+            description="Minimum percentage of the bond constituted by f atomic orbitals on the first atom.",
         ),
         max_f_character_atom1: Optional[float] = Query(
             None,
-            description="Maximum percentage of the bond constituted by f atomic orbitals on the first atom."
+            description="Maximum percentage of the bond constituted by f atomic orbitals on the first atom.",
         ),
         min_f_character_atom2: Optional[float] = Query(
             None,
-            description="Minimum percentage of the bond constituted by f atomic orbitals on the second atom."
+            description="Minimum percentage of the bond constituted by f atomic orbitals on the second atom.",
         ),
         max_f_character_atom2: Optional[float] = Query(
             None,
-            description="Maximum percentage of the bond constituted by f atomic orbitals on the second atom."
+            description="Maximum percentage of the bond constituted by f atomic orbitals on the second atom.",
         ),
         min_polarization_atom1: Optional[float] = Query(
             None,
-            description="Minimum fraction of electrons in the bond donated by the first atom."
+            description="Minimum fraction of electrons in the bond donated by the first atom.",
         ),
         max_polarization_atom1: Optional[float] = Query(
             None,
-            description="Maximum fraction of electrons in the bond donated by the first atom."
+            description="Maximum fraction of electrons in the bond donated by the first atom.",
         ),
         min_polarization_atom2: Optional[float] = Query(
             None,
-            description="Minimum fraction of electrons in the bond donated by the second atom."
+            description="Minimum fraction of electrons in the bond donated by the second atom.",
         ),
         max_polarization_atom2: Optional[float] = Query(
             None,
-            description="Maximum fraction of electrons in the bond donated by the second atom."
+            description="Maximum fraction of electrons in the bond donated by the second atom.",
         ),
         min_bond_occupancy: Optional[float] = Query(
-            None,
-            description="Minimum number of electrons in the bond."
+            None, description="Minimum number of electrons in the bond."
         ),
         max_bond_occupancy: Optional[float] = Query(
-            None,
-            description="Maximum number of electrons in the bond."
+            None, description="Maximum number of electrons in the bond."
         ),
     ) -> STORE_PARAMS:
         crit: Dict[str, Any] = dict()  # type: ignore
@@ -341,9 +344,13 @@ class NBOBondQuery(QueryOperator):
                 elif electron_type_bond.lower() == "beta":
                     prefix = "beta_bonds."
                 else:
-                    raise ValueError("electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!")
+                    raise ValueError(
+                        "electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!"
+                    )
             except AttributeError:
-                raise ValueError("electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!")
+                raise ValueError(
+                    "electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!"
+                )
 
         for entry in d:
             key = prefix + entry
@@ -375,7 +382,7 @@ class NBOBondQuery(QueryOperator):
             "atom1_polarization",
             "atom2_polarization",
             "occupancy",
-            "type_code"
+            "type_code",
         ]
         indices = list()
         for p in prefixes:
@@ -391,39 +398,33 @@ class NBOInteractionQuery(QueryOperator):
         self,
         electron_type_interaction: Optional[str] = Query(
             None,
-            description="Should alpha ('alpha'), beta ('beta'), or all electrons be considered (None; default)?"
+            description="Should alpha ('alpha'), beta ('beta'), or all electrons be considered (None; default)?",
         ),
         donor_type: Optional[str] = Query(
             None,
-            description="Type of donor orbital, e.g. 'BD' for bonding or 'RY*' for anti-Rydberg"
+            description="Type of donor orbital, e.g. 'BD' for bonding or 'RY*' for anti-Rydberg",
         ),
         acceptor_type: Optional[str] = Query(
             None,
-            description="Type of acceptor orbital, e.g. 'BD' for bonding or 'RY*' for anti-Rydberg"
+            description="Type of acceptor orbital, e.g. 'BD' for bonding or 'RY*' for anti-Rydberg",
         ),
         min_perturbation_energy: Optional[float] = Query(
-            None,
-            description="Minimum perturbation energy of the interaction"
+            None, description="Minimum perturbation energy of the interaction"
         ),
         max_perturbation_energy: Optional[float] = Query(
-            None,
-            description="Maximum perturbation energy of the interaction"
+            None, description="Maximum perturbation energy of the interaction"
         ),
         min_energy_difference: Optional[float] = Query(
-            None,
-            description="Minimum energy difference between interacting orbitals"
+            None, description="Minimum energy difference between interacting orbitals"
         ),
         max_energy_difference: Optional[float] = Query(
-            None,
-            description="Minimum energy difference between interacting orbitals"
+            None, description="Minimum energy difference between interacting orbitals"
         ),
         min_fock_element: Optional[float] = Query(
-            None,
-            description="Minimum interaction Fock matrix element"
+            None, description="Minimum interaction Fock matrix element"
         ),
         max_fock_element: Optional[float] = Query(
-            None,
-            description="Maximum interaction Fock matrix element"
+            None, description="Maximum interaction Fock matrix element"
         ),
     ) -> STORE_PARAMS:
         crit: Dict[str, Any] = dict()  # type: ignore
@@ -443,9 +444,13 @@ class NBOInteractionQuery(QueryOperator):
                 elif electron_type_interaction.lower() == "beta":
                     prefix = "beta_interactions."
                 else:
-                    raise ValueError("electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!")
+                    raise ValueError(
+                        "electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!"
+                    )
             except AttributeError:
-                raise ValueError("electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!")
+                raise ValueError(
+                    "electron_type must be 'alpha' or 'beta' (open-shell), or None (closed-shell)!"
+                )
 
         for entry in d:
             key = prefix + entry
