@@ -18,10 +18,18 @@ def test_user_settings_post_query():
         dumpfn(op, "temp.json")
         new_op = loadfn("temp.json")
         query = {
-            "criteria": {"consumer_id": "test", "settings": {"test": "test", "test2": 10},}
+            "criteria": {
+                "consumer_id": "test",
+                "settings": {"test": "test", "test2": 10},
+            }
         }
-        assert new_op.query(consumer_id="test", settings={"test": "test", "test2": 10}) == {
-            "criteria": {"consumer_id": "test", "settings": {"test": "test", "test2": 10},}
+        assert new_op.query(
+            consumer_id="test", settings={"test": "test", "test2": 10}
+        ) == {
+            "criteria": {
+                "consumer_id": "test",
+                "settings": {"test": "test", "test2": 10},
+            }
         }
 
     docs = [{"consumer_id": "test", "settings": {"test": "test", "test2": 10}}]
