@@ -1,4 +1,6 @@
-from emmet.api.routes.materials.oxidation_states.query_operators import PossibleOxiStateQuery
+from emmet.api.routes.materials.oxidation_states.query_operators import (
+    PossibleOxiStateQuery,
+)
 
 from monty.tempfile import ScratchDir
 from monty.serialization import loadfn, dumpfn
@@ -13,7 +15,7 @@ def test_possible_oxi_state_query():
 
     with ScratchDir("."):
         dumpfn(op, "temp.json")
-        new_op = loadfn("temp.json")
+        loadfn("temp.json")
 
         assert op.query(possible_species="Cr2+, O2-") == {
             "criteria": {"possible_species": {"$all": ["Cr2+", "O2-"]}}
