@@ -1,4 +1,6 @@
-from emmet.api.routes.materials.surface_properties.query_operators import ReconstructedQuery
+from emmet.api.routes.materials.surface_properties.query_operators import (
+    ReconstructedQuery,
+)
 
 
 from monty.tempfile import ScratchDir
