@@ -4,7 +4,10 @@ from json import load
 from pymatgen.core import Composition
 
 from emmet.api.core.settings import MAPISettings
-from emmet.api.routes.materials.synthesis.data_adaptor import string2comp, convert_recipe
+from emmet.api.routes.materials.synthesis.data_adaptor import (
+    string2comp,
+    convert_recipe,
+)
 
 
 def test_string2comp():
