@@ -1,6 +1,4 @@
-from emmet.api.routes.molecules.redox.query_operators import (
-    RedoxPotentialQuery
-)
+from emmet.api.routes.molecules.redox.query_operators import RedoxPotentialQuery
 from monty.tempfile import ScratchDir
 from monty.serialization import loadfn, dumpfn
 
@@ -8,15 +6,14 @@ from monty.serialization import loadfn, dumpfn
 def test_redox_potential_query():
     op = RedoxPotentialQuery()
     assert op.query(
-        electrode="Li",
         min_reduction_potential=0.0,
         max_reduction_potential=0.8,
         min_oxidation_potential=4.0,
-        max_oxidation_potential=6.0
+        max_oxidation_potential=6.0,
     ) == {
-        'criteria': {
-            'oxidation_potentials.Li': {'$gte': 4.0, '$lte': 6.0},
-            'reduction_potentials.Li': {'$gte': 0.0, '$lte': 0.8}
+        "criteria": {
+            "oxidation_potential": {"$gte": 4.0, "$lte": 6.0},
+            "reduction_potential": {"$gte": 0.0, "$lte": 0.8},
         }
     }
 
@@ -24,14 +21,13 @@ def test_redox_potential_query():
         dumpfn(op, "temp.json")
         new_op = loadfn("temp.json")
         assert new_op.query(
-            electrode="Li",
             min_reduction_potential=0.0,
             max_reduction_potential=0.8,
             min_oxidation_potential=4.0,
-            max_oxidation_potential=6.0
+            max_oxidation_potential=6.0,
         ) == {
-            'criteria': {
-                'oxidation_potentials.Li': {'$gte': 4.0, '$lte': 6.0},
-                'reduction_potentials.Li': {'$gte': 0.0, '$lte': 0.8}
+            "criteria": {
+                "oxidation_potential": {"$gte": 4.0, "$lte": 6.0},
+                "reduction_potential": {"$gte": 0.0, "$lte": 0.8},
             }
         }
